@@ -1,5 +1,8 @@
 #! /bin/sh
 
+# Where to find mkpkgadd
+MKPKGADD=$1
+
 # Create a new fntests.m file
 echo "fid=fopen('fntests.log','wt');" > fntests.m
 echo "if fid<0,error('could not open fntests.log for writing');end" >>fntests.m
@@ -11,11 +14,16 @@ DIRS="`find FIXES main/* extra/* nonfree/* -type d ! -name CVS -prune`"
 
 # Find the tests in that directory
 for dir in $DIRS; do
-    dir=${dir#./}
+    dir=`echo $dir | sed -e "s-^\./--" `
 
     # skip the NOINSTALL directories
     if test -f "$dir/NOINSTALL"; then continue; fi
 
+    # Create local copy of PKG_ADD for in place testing
+    if test -e "$dir/PKG_ADD" ; then rm -f $dir/PKG_ADD; fi
+    $MKPKGADD $dir > $dir/PKG_ADD
+    if test -z "`cat $dir/PKG_ADD`" ; then rm -f $dir/PKG_ADD;  fi
+ 
     # Build a list of possible test files
     FILES=""
 
@@ -23,7 +31,8 @@ for dir in $DIRS; do
     cxx_files=`echo $dir/*.cc`
     if test "$cxx_files" != "$dir/*.cc"; then 
 	for file in $cxx_files; do
-	    if test -f ${file%.cc}.o; then FILES="$FILES $file"; fi
+      	    obj=`echo "$file" | sed -e 's-\.cc$-.o-'`
+	    if test -f "$obj" ; then FILES="$FILES $file"; fi
 	done
     fi
 
