@@ -106,11 +106,11 @@ function retval = fixedpoint(typ, tests)
       len = length(infopath);
       if (len)
         if (len > 1 && strcmp(infopath([len-1, len]),"//"))
-          showfile = system(["find '", infopath(1:len-1), "' -name ", ...
-                             infofile]);
+          [status, showfile] = system(["find '", infopath(1:len-1), ...
+				       "' -name ", infofile]);
         else
-          showfile = system(["find '", infopath, "' -name ", infofile, ...
-                             " -maxdepth 1"]);
+          [status, showfile] = system(["find '", infopath, "' -name ", ...
+				       infofile, " -maxdepth 1"]);
         endif
         if (length(showfile))
           break;
@@ -125,7 +125,7 @@ function retval = fixedpoint(typ, tests)
     endif
     
     if (exist("INFO_PROGAM")) 
-      [testout, testret] = system(["'", INFO_PROGRAM, "' --version"]);
+      [testret, testout] = system(["'", INFO_PROGRAM, "' --version"]);
       if (testret)
         error("fixedpoint: info command not found");
       else
@@ -133,7 +133,7 @@ function retval = fixedpoint(typ, tests)
                 nodename, "'"]); 
       endif
     else
-      [testout, testret] = system("info --version");
+      [testret, testout] = system("info --version");
       if (testret)
         error("fixedpoint: info command not found");
       else
@@ -1691,21 +1691,21 @@ function ret = _fixedpoint_test_function(func,is,ds,n,eps,includezero)
   if (includezero)
     t1 = eval([ func "(tczero);"]);
     f1 = eval([ ffunc "(fczero);"]);
-    if ((abs(real(t1) - real(f1).x) > eps) || 
-	(abs(imag(t1) - imag(f1).x) > eps))
+    if ((abs(real(t1) - freal(f1).x) > eps) || 
+	(abs(imag(t1) - fimag(f1).x) > eps))
       ret = 1;
       return;
     endif
   endif
   t1 = eval([ func "(tcone);"]);
   f1 = eval([ ffunc "(fcone);"]);
-  if ((abs(real(t1) - real(f1).x) > eps) || (abs(imag(t1) - imag(f1).x) > eps))
+  if ((abs(real(t1) - freal(f1).x) > eps) || (abs(imag(t1) - fimag(f1).x) > eps))
     ret = 1;
     return;
   endif
   t1 = eval([ func "(tcval);"]);
   f1 = eval([ ffunc "(fcval);"]);
-  if ((abs(real(t1) - real(f1).x) > eps) || (abs(imag(t1) - imag(f1).x) > eps))
+  if ((abs(real(t1) - freal(f1).x) > eps) || (abs(imag(t1) - fimag(f1).x) > eps))
     ret = 1;
     return;
   endif
@@ -1714,23 +1714,23 @@ function ret = _fixedpoint_test_function(func,is,ds,n,eps,includezero)
   if (includezero)
     t1 = eval([ func "(tczeros);"]);
     f1 = eval([ ffunc "(fczeros);"]);
-    if (any(any(abs(real(t1) - real(f1).x) > eps)) || 
-	any(any(abs(imag(t1) - imag(f1).x) > eps)))
+    if (any(any(abs(real(t1) - freal(f1).x) > eps)) || 
+	any(any(abs(imag(t1) - fimag(f1).x) > eps)))
       ret = 1;
       return;
     endif
   endif
   t1 = eval([ func "(tcones);"]);
   f1 = eval([ ffunc "(fcones);"]);
-  if (any(any(abs(real(t1) - real(f1).x) > eps)) || 
-      any(any(abs(imag(t1) - imag(f1).x) > eps)))
+  if (any(any(abs(real(t1) - freal(f1).x) > eps)) || 
+      any(any(abs(imag(t1) - fimag(f1).x) > eps)))
     ret = 1;
     return;
   endif
   t1 = eval([ func "(tcvals);"]);
   f1 = eval([ ffunc "(fcvals);"]);
-  if (any(any(abs(real(t1) - real(f1).x) > eps)) || 
-      any(any(abs(imag(t1) - imag(f1).x) > eps)))
+  if (any(any(abs(real(t1) - freal(f1).x) > eps)) || 
+      any(any(abs(imag(t1) - fimag(f1).x) > eps)))
     ret = 1;
     return;
   endif
