@@ -7,7 +7,7 @@
  * Do what you like with this code as long as you
  *     leave this copyright in place.
  *
- * $Id: rotate_scale.cc,v 1.2 2005/04/22 17:29:42 aadler Exp $
+ * $Id: rotate_scale.cc,v 1.3 2006/05/19 06:58:50 jwe Exp $
  */
 
 #include <octave/oct.h>
@@ -58,7 +58,7 @@ DEFUN_DLD (rotate_scale, args, ,
        !args(2).is_matrix_type() ||
        !args(3).is_matrix_type()
        ) {
-      print_usage ("rotate_scale");
+      print_usage ();
       return retval;
    }
 
