@@ -1,5 +1,5 @@
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{p}, @var{s}] =} wpolyfit (@var{x}, @var{y}, @var{dy}, @var{n}, 'origin')
+## @deftypefn {Function File} {[@var{p}, @var{s}] =} wpolyfit (@var{x}, @var{y}, @var{dy}, @var{n})
 ## Return the coefficients of a polynomial @var{p}(@var{x}) of degree
 ## @var{n} that minimizes
 ## @iftex
@@ -19,12 +19,6 @@
 ## suitable for use in the function polyval.  The structure @var{s} returns
 ## information necessary to compute uncertainty in the model.
 ##
-## If no output arguments are requested, then wpolyfit plots the data,
-## the fitted line and polynomials defining the standard error range.
-##
-## If 'origin' is specified, then the fitted polynomial will go through
-## the origin.  This is generally ill-advised.  Use with caution.
-##
 ## To compute the predicted values of y with uncertainty use
 ## @example
 ## [y,dy] = polyconf(p,x,s,'ci');
@@ -65,6 +59,19 @@
 ## but the high degree of covariance amongst them makes this a questionable
 ## operation.
 ##
+## @deftypefnx {Function File} {[@var{p}, @var{s}, @var{mu}] =} wpolyfit (...)
+##
+## If an additional output @code{mu = [mean(x),std(x)]} is requested then 
+## the @var{x} values are centered and normalized prior to computing the fit.
+## This will give more stable numerical results.  To compute a predicted 
+## @var{y} from the returned model use
+## @code{y = polyval(p, (x-mu(1))/mu(2)}
+##
+## @deftypefnx {Function File} wpolyfit (...)
+##
+## If no output arguments are requested, then wpolyfit plots the data,
+## the fitted line and polynomials defining the standard error range.
+##
 ## Example
 ## @example
 ## x = linspace(0,4,20);
@@ -73,6 +80,11 @@
 ## wpolyfit(x,y,dy,2);
 ## @end example
 ##
+## @deftypefnx {Function File} wpolyfit (..., 'origin')
+##
+## If 'origin' is specified, then the fitted polynomial will go through
+## the origin.  This is generally ill-advised.  Use with caution.
+##
 ## Hocking, RR (2003). Methods and Applications of Linear Models.
 ## New Jersey: John Wiley and Sons, Inc.
 ##
@@ -83,11 +95,11 @@
 ## This program is in the public domain.
 ## Author: Paul Kienzle <pkienzle@users.sf.net>
 
-function [p_out, s] = wpolyfit (varargin)
+function [p_out, s, mu] = wpolyfit (varargin)
 
   ## strip 'origin' of the end
   args = length(varargin);
-  if args>0 && isstr(varargin{args})
+  if args>0 && ischar(varargin{args})
     origin = varargin{args};
     args--;
   else
@@ -142,6 +154,11 @@ function [p_out, s] = wpolyfit (varargin)
     error ("wpolyfit: n must be a nonnegative integer");
   endif
 
+  if nargout == 3
+    mu = [mean(x), std(x)];
+    x = (x - mu(1))/mu(2);
+  endif
+
   k = length (x);
 
   ## observation matrix
@@ -164,7 +181,7 @@ function [p_out, s] = wpolyfit (varargin)
     printf("Polynomial: %s  [ p(chi^2>observed)=%.2f%% ]\n", polyout(p,'x'), good_fit*100);
     plt(x,y,dy,p,s,'ci');
   else
-    p_out = p;
+    p_out = p';
   endif
 
 function plt(x,y,dy,p,s,varargin)
