@@ -47,7 +47,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 bool get_expression(const octave_value arg, GiNaC::ex& expression)
 {
-  const octave_value& rep = (arg).get_rep();
+  const OV_REP_TYPE& rep = (arg).get_rep();
 
   if (arg.type_id () == octave_vpa::static_type_id ())
     {
@@ -74,7 +74,7 @@ bool get_expression(const octave_value arg, GiNaC::ex& expression)
 
 bool get_symbol(const octave_value arg, GiNaC::ex& sym)
 {
-  const octave_value& rep = arg.get_rep ();
+  const OV_REP_TYPE& rep = arg.get_rep ();
   GiNaC::ex x; 
   if (arg.type_id () == octave_ex::static_type_id ())
     x = ((octave_ex& ) rep).ex_value();
@@ -91,7 +91,7 @@ bool get_symbol(const octave_value arg, GiNaC::ex& sym)
 
 bool get_numeric(const octave_value arg, GiNaC::numeric& number)
 {
-  const octave_value& rep = arg.get_rep ();
+  const OV_REP_TYPE& rep = arg.get_rep ();
 
   if (arg.type_id () == octave_ex::static_type_id ())
     {
@@ -115,7 +115,7 @@ bool get_numeric(const octave_value arg, GiNaC::numeric& number)
 
 bool get_relation(const octave_value arg, GiNaC::relational& relation)
 {
-	const octave_value& rep = arg.get_rep();
+	const OV_REP_TYPE& rep = arg.get_rep();
 	if (arg.type_id () == octave_relational::static_type_id ()) {
 		GiNaC::relational x = ((octave_relational& ) rep).relational_value();
 		relation = x;
@@ -153,7 +153,7 @@ Convert a vpa, string, ex or string type to a double.\n\
 
   if (nargin != 1)
     {
-      print_usage("to_double");
+      print_usage ();
       return retval;
     }
 
@@ -161,7 +161,7 @@ Convert a vpa, string, ex or string type to a double.\n\
     {
       if (!get_numeric (args(0), num))
 	{
-	  print_usage("to_double");
+	  print_usage ();
 	  return retval;
 	}
       
@@ -202,7 +202,7 @@ Change the precision for the vpa type\n\
 	    }
 	  else
 	    {
-	      print_usage("digits");
+	      print_usage ();
 	    }
 	}
 
@@ -373,7 +373,7 @@ Expand an expression\n\
 
   if(args.length() != 1)
     {
-      print_usage("expand");
+      print_usage ();
       return retval;
     }
 
@@ -382,7 +382,7 @@ Expand an expression\n\
 
       if(args(0).type_id() == octave_ex::static_type_id())
 	{
-	  const octave_value& rep1 = args(0).get_rep();
+	  const OV_REP_TYPE& rep1 = args(0).get_rep();
 	  expression = ((const octave_ex& ) rep1).ex_value();
 	}
       else
@@ -419,7 +419,7 @@ Obtain the @var{n}th coefficient of the variable @var{x} in @var{a}.\n\
 
   if(args.length () != 3)
     {
-      print_usage("coeff");
+      print_usage ();
       return retval;
     }
 
@@ -479,7 +479,7 @@ collect the terms in @var{a} as a univariate polynomial in @var{x}\n\
 
   if(args.length() != 2)
     {
-      print_usage("collect");
+      print_usage ();
       return retval;
     }
 
@@ -528,7 +528,7 @@ Collect the terms in @var{a} as a univariate polynomial in @var{x}\n\
 
   if(args.length() != 2)
     {
-      print_usage("collect");
+      print_usage ();
       return retval;
     }
 
